# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

***
## [Unreleased] - XXXXX-XX-XX
### Enhanced
- None

### Added
- None

### Changed
- None

### Deprecated
- None

### Removed
- None

### Fixed
-  None

### Security
- None

### Known Issues
- None

***
## [1.2.2] - 2018-10-26
### Fixed
- [Issue #35](https://gitlab.aldebaran.lan/production/wooqi/issues/35): Update dependencies versions required.

***
## [1.2.1] - 2018-08-07
### Enhanced
- [Issue #21](https://gitlab.aldebaran.lan/production/wooqi/issues/21): Add possibility to give 3 arguments to range().
- [Issue #31](https://gitlab.aldebaran.lan/production/wooqi/issues/31): Wooqi project - place actions in test_steps folder.

### Added
- [Issue #32](https://gitlab.aldebaran.lan/production/wooqi/issues/32): Manage postfail_feature_management when teardown fail.

### Fixed
- [Issue #33](https://gitlab.aldebaran.lan/production/wooqi/issues/33): Wooqi command return correctly signal number

***
## [1.2.0] - 2017-10-31
### Added
- [Issue #24](https://gitlab.aldebaran.lan/production/wooqi/issues/24): recurse_folders as uut parameter.
- [Issue #25](https://gitlab.aldebaran.lan/production/wooqi/issues/25): Add LICENSE file and headers.

***
## [1.1.0] - 2017-08-30
### Enhanced
- Improve version display.
- [Issue #17](https://gitlab.aldebaran.lan/production/wooqi/issues/17): Keep capital in test_info keys.

### Added
- Possibility to rerun sequence since the first test failed.

### Changed
- Split Wooqi tests.

***
## [1.0.2] - 2017-05-18
### Fixed
- Fix exit status.

***
## [1.0.1] - 2017-04-21
### Added
- --init-project option to create a new Wooqi project.
- AUTHORS file.

***
## [1.0.0] - 2017-03-29
*First official release.*

[Unreleased]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.1.0...master
[1.2.2]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.2.1...v1.2.2
[1.2.1]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.2.0...v1.2.1
[1.2.0]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.1.0...v1.2.0
[1.1.0]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.0.2...v1.1.0
[1.0.2]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.0.1...v1.0.2
[1.0.1]: https://gitlab.aldebaran.lan/production/wooqi/compare/v1.0.0...v1.0.1
[1.0.0]: https://gitlab.aldebaran.lan/production/wooqi/compare/2bcd8e8d1...v1.0.0
